package com.ruoyi.warehouse.mapper;

import java.util.List;
import com.ruoyi.warehouse.domain.WarehouseArea;

public interface WarehouseAreaMapper
{
    public List<WarehouseArea> selectWarehouseAreaList(WarehouseArea warehouseArea);

    public List<WarehouseArea> selectWarehouseAreaAll();

    public WarehouseArea selectWarehouseAreaById(Long id);

    public WarehouseArea checkAreaCodeUnique(String areaCode);

    public int insertWarehouseArea(WarehouseArea warehouseArea);

    public int updateWarehouseArea(WarehouseArea warehouseArea);

    public int deleteWarehouseAreaByIds(Long[] ids);
}
